==> agrum_1.3.1.orig.tar.bz2: aGrUM-1.3.1/src/testunits/module_BASE/UtilsStringTestSuite.h <==
/**
 *
 *   Copyright (c) 2005-2022 by Pierre-Henri WUILLEMIN(_at_LIP6) & Christophe GONZALES(_at_AMU)
 *   info_at_agrum_dot_org
 *
 *  This library is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 */


#include <gumtest/AgrumTestSuite.h>
#include <gumtest/testsuite_utils.h>

#include <agrum/tools/core/utils_string.h>

namespace gum_tests {

  class UtilsStringTestSuite: public CxxTest::TestSuite {
    public:
    void TestIsInteger() {
      TS_ASSERT(gum::isInteger("12"))
      TS_ASSERT(!gum::isInteger("foo"))
      TS_ASSERT(!gum::isInteger("12foo"))
      TS_ASSERT(!gum::isInteger("foo12"))
      TS_ASSERT(!gum::isInteger("foo12bar"))

      TS_ASSERT(gum::isInteger("+12"))
      TS_ASSERT(!gum::isInteger("1+2"))

      TS_ASSERT(gum::isInteger("-12"))
      TS_ASSERT(!gum::isInteger("1-2"))
    }

    void TestisNumerical() {
      TS_ASSERT(gum::isNumerical("12"))
      TS_ASSERT(!gum::isNumerical("foo"))
      TS_ASSERT(!gum::isNumerical("12foo"))
      TS_ASSERT(!gum::isNumerical("foo12"))
      TS_ASSERT(!gum::isNumerical("foo12bar"))

      TS_ASSERT(gum::isNumerical("12.5"))
      TS_ASSERT(!gum::isNumerical("12.5foo"))
      TS_ASSERT(!gum::isNumerical("foo12.5"))
      TS_ASSERT(!gum::isNumerical("foo12.5bar"))

      TS_ASSERT(gum::isNumerical("+12"))
      TS_ASSERT(!gum::isNumerical("1+2"))

      TS_ASSERT(gum::isNumerical("-12"))
      TS_ASSERT(!gum::isNumerical("1-2"))

      TS_ASSERT(gum::isNumerical("-1.2"))
      TS_ASSERT(gum::isNumerical("1.2"))
      TS_ASSERT(gum::isNumerical("+1.2"))
      TS_ASSERT(gum::isNumerical("1.2e-8"))
    }


    void TestIsIntegerWithResult() {
      int res;
      TS_ASSERT(gum::isIntegerWithResult("12", &res))
      TS_ASSERT_EQUALS(res, 12)
      TS_ASSERT(!gum::isIntegerWithResult("foo", &res))
      TS_ASSERT(!gum::isIntegerWithResult("12foo", &res))
      TS_ASSERT(!gum::isIntegerWithResult("foo12", &res))
      TS_ASSERT(!gum::isIntegerWithResult("foo12bar", &res))

      TS_ASSERT(gum::isIntegerWithResult("+12", &res))
      TS_ASSERT_EQUALS(res, 12)
      TS_ASSERT(!gum::isIntegerWithResult("1+2", &res))

      TS_ASSERT(gum::isIntegerWithResult("-12", &res))
      TS_ASSERT_EQUALS(res, -12)
      TS_ASSERT(!gum::isIntegerWithResult("1-2", &res))
    }

    void TestisNumericalWithResWithResult() {
      double res;
      TS_ASSERT(gum::isNumericalWithResult("12", &res))
      TS_ASSERT_EQUALS(res, 12.0)
      TS_ASSERT(!gum::isNumericalWithResult("foo", &res))
      TS_ASSERT(!gum::isNumericalWithResult("12foo", &res))
      TS_ASSERT(!gum::isNumericalWithResult("foo12", &res))
      TS_ASSERT(!gum::isNumericalWithResult("foo12bar", &res))

      TS_ASSERT(gum::isNumericalWithResult("12.5", &res))
      TS_ASSERT_EQUALS(res, 12.5)
      TS_ASSERT(!gum::isNumericalWithResult("12.5foo", &res))
      TS_ASSERT(!gum::isNumericalWithResult("foo12.5", &res))
      TS_ASSERT(!gum::isNumericalWithResult("foo12.5bar", &res))

      TS_ASSERT(gum::isNumericalWithResult("+12", &res))
      TS_ASSERT_EQUALS(res, 12.0)
      TS_ASSERT(!gum::isNumericalWithResult("1+2", &res))

      TS_ASSERT(gum::isNumericalWithResult("-12", &res))
      TS_ASSERT_EQUALS(res, -12.0)
      TS_ASSERT(!gum::isNumericalWithResult("1-2", &res))

      TS_ASSERT(gum::isNumericalWithResult("-1.2", &res))
      TS_ASSERT(gum::isNumericalWithResult("1.2", &res))
      TS_ASSERT_EQUALS(res, 1.2)
      TS_ASSERT(gum::isNumericalWithResult("+1.2", &res))
      TS_ASSERT_EQUALS(res, 1.2)
      TS_ASSERT(gum::isNumericalWithResult("1.2e-8", &res))
      TS_ASSERT_EQUALS(res, 1.2e-8)
    }
  };
}   // namespace gum_tests

==> agrum_1.8.0.orig.tar.bz2: aGrUM-1.8.0/src/testunits/module_BASE/UtilsStringTestSuite.h <==
/**
 *
 *   Copyright (c) 2005-2023 by Pierre-Henri WUILLEMIN(_at_LIP6) & Christophe GONZALES(_at_AMU)
 *   info_at_agrum_dot_org
 *
 *  This library is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 */


#include <gumtest/AgrumTestSuite.h>
#include <gumtest/testsuite_utils.h>

#include <agrum/tools/core/utils_string.h>

namespace gum_tests {

  class [[maybe_unused]] UtilsStringTestSuite: public CxxTest::TestSuite {
    public:
    GUM_ACTIVE_TEST(IsInteger){
       TS_ASSERT(gum::isInteger("12")) TS_ASSERT(!gum::isInteger("foo"))
          TS_ASSERT(!gum::isInteger("12foo")) TS_ASSERT(!gum::isInteger("foo12"))
             TS_ASSERT(!gum::isInteger("foo12bar"))

                TS_ASSERT(gum::isInteger("+12")) TS_ASSERT(!gum::isInteger("1+2"))

                   TS_ASSERT(gum::isInteger("-12")) TS_ASSERT(!gum::isInteger("1-2"))}

    GUM_ACTIVE_TEST(isNumerical){
       TS_ASSERT(gum::isNumerical("12")) TS_ASSERT(!gum::isNumerical("foo"))
          TS_ASSERT(!gum::isNumerical("12foo")) TS_ASSERT(!gum::isNumerical("foo12"))
             TS_ASSERT(!gum::isNumerical("foo12bar"))

                TS_ASSERT(gum::isNumerical("12.5")) TS_ASSERT(!gum::isNumerical("12.5foo"))
                   TS_ASSERT(!gum::isNumerical("foo12.5"))
                      TS_ASSERT(!gum::isNumerical("foo12.5bar"))

                         TS_ASSERT(gum::isNumerical("+12")) TS_ASSERT(!gum::isNumerical("1+2"))

                            TS_ASSERT(gum::isNumerical("-12")) TS_ASSERT(!gum::isNumerical("1-2"))

                               TS_ASSERT(gum::isNumerical("-1.2"))
                                  TS_ASSERT(gum::isNumerical("1.2"))
                                     TS_ASSERT(gum::isNumerical("+1.2"))
                                        TS_ASSERT(gum::isNumerical("1.2e-8"))}


    GUM_ACTIVE_TEST(IsIntegerWithResult) {
      int res;
      TS_ASSERT(gum::isIntegerWithResult("12", &res))
      TS_ASSERT_EQUALS(res, 12)
      TS_ASSERT(!gum::isIntegerWithResult("foo", &res))
      TS_ASSERT(!gum::isIntegerWithResult("12foo", &res))
      TS_ASSERT(!gum::isIntegerWithResult("foo12", &res))
      TS_ASSERT(!gum::isIntegerWithResult("foo12bar", &res))

      TS_ASSERT(gum::isIntegerWithResult("+12", &res))
      TS_ASSERT_EQUALS(res, 12)
      TS_ASSERT(!gum::isIntegerWithResult("1+2", &res))

      TS_ASSERT(gum::isIntegerWithResult("-12", &res))
      TS_ASSERT_EQUALS(res, -12)
      TS_ASSERT(!gum::isIntegerWithResult("1-2", &res))
    }

    GUM_ACTIVE_TEST(isNumericalWithResWithResult) {
      double res;
      TS_ASSERT(gum::isNumericalWithResult("12", &res))
      TS_ASSERT_EQUALS(res, 12.0)
      TS_ASSERT(!gum::isNumericalWithResult("foo", &res))
      TS_ASSERT(!gum::isNumericalWithResult("12foo", &res))
      TS_ASSERT(!gum::isNumericalWithResult("foo12", &res))
      TS_ASSERT(!gum::isNumericalWithResult("foo12bar", &res))

      TS_ASSERT(gum::isNumericalWithResult("12.5", &res))
      TS_ASSERT_EQUALS(res, 12.5)
      TS_ASSERT(!gum::isNumericalWithResult("12.5foo", &res))
      TS_ASSERT(!gum::isNumericalWithResult("foo12.5", &res))
      TS_ASSERT(!gum::isNumericalWithResult("foo12.5bar", &res))

      TS_ASSERT(gum::isNumericalWithResult("+12", &res))
      TS_ASSERT_EQUALS(res, 12.0)
      TS_ASSERT(!gum::isNumericalWithResult("1+2", &res))

      TS_ASSERT(gum::isNumericalWithResult("-12", &res))
      TS_ASSERT_EQUALS(res, -12.0)
      TS_ASSERT(!gum::isNumericalWithResult("1-2", &res))

      TS_ASSERT(gum::isNumericalWithResult("-1.2", &res))
      TS_ASSERT(gum::isNumericalWithResult("1.2", &res))
      TS_ASSERT_EQUALS(res, 1.2)
      TS_ASSERT(gum::isNumericalWithResult("+1.2", &res))
      TS_ASSERT_EQUALS(res, 1.2)
      TS_ASSERT(gum::isNumericalWithResult("1.2e-8", &res))
      TS_ASSERT_EQUALS(res, 1.2e-8)
    }
  };
}   // namespace gum_tests
